@@ -22,11 +22,22 @@ SettingsDialog::SettingsDialog( QWidget *parent )
     {
         Ui::VisualSettings ui;
         ui.setupUi( page );
+        switch ( Settings::displayStyle() ) {
+            case Settings::EnumDisplayStyle::ScrollingText:
+                ui.stackedWidget->setCurrentIndex( 0 );
+            case Settings::EnumDisplayStyle::PagedText:
+                ui.stackedWidget->setCurrentIndex( 1 );
+                break;
+            // Added by KConfigXT for internal reasons.
+            case Settings::EnumDisplayStyle::COUNT:
+                break;
+        }
     }
     addPage( page, i18n( "Appearance" ) );
 
     m_feedSettingsWidget = new FeedSettingsWidget( 0 );
     addPage( m_feedSettingsWidget, i18n( "Feed Access" ) );
+    setHelp(QString(),"knewsticker");
 }
 
 QStringList SettingsDialog::feedUrls() const
