@@ -39,6 +39,7 @@
 #include <QtGui/QCursor>
 #include <QtGui/QPixmap>
 #include <QtGui/QTextDocument>
+#include <QtGui/QScrollBar>
 #include <QMimeData>
 #include <QApplication>
 
@@ -231,9 +232,8 @@ ChatMessagePart::ChatMessagePart( Kopete::ChatSession *mgr, QWidget *parent )
 
 	connect( this, SIGNAL(popupMenu(const QString &, const QPoint &)),
 	         this, SLOT(slotRightClick(const QString &, const QPoint &)) );
-	// FIXME no longer compiles
-	//connect( view()->horizontalScrollBar(), SIGNAL(sliderMoved(int)),
-	//         this, SLOT(slotScrollingTo(int)) );
+	connect( view()->verticalScrollBar(), SIGNAL(sliderMoved(int)),
+	         this, SLOT(slotScrollingTo(int)) );
 
 	//initActions
 	d->copyAction = KStandardAction::copy( this, SLOT(copy()), actionCollection() );
@@ -982,12 +982,13 @@ QString ChatMessagePart::formatStyleKeywords( const QString &sourceHTML )
 {
 	QString resultHTML = sourceHTML;
 
-	Kopete::Contact *remoteContact = d->manager->members().first();
-
 	// Verify that all contacts are not null before doing anything
-	if( remoteContact && d->manager->myself() )
+	if( !d->manager->members().isEmpty() && d->manager->myself() )
 	{
 		QString sourceName, destinationName;
+
+		Kopete::Contact *remoteContact = d->manager->members().first();
+
 		// Use contact nickname for ourselfs, Myself metacontact display name isn't a reliable source.
 		sourceName = d->manager->myself()->nickName();
 		if( remoteContact->metaContact() )
