@@ -258,7 +258,14 @@ void ChatView::setFont( const QFont &font )
 
 void ChatView::setFgColor( const QColor &newColor )
 {
-	editPart()->setTextColor( newColor );
+    if ( newColor.isValid() )
+	{
+		editPart()->setTextColor( newColor );
+    }
+	else
+	{
+		editPart()->setTextColor();
+    }
 }
 
 void ChatView::raise( bool activate )
@@ -279,7 +286,7 @@ void ChatView::raise( bool activate )
 #endif
 	if(m_mainWindow->isMinimized())
 	{
-		m_mainWindow->showNormal();
+		KWindowSystem::unminimizeWindow( m_mainWindow->winId());
 	}
 
 
@@ -673,7 +680,7 @@ void ChatView::slotContactStatusChanged( Kopete::Contact *contact, const Kopete:
  	kDebug(14000) << contact;
 	bool inhibitNotification = ( newStatus.status() == Kopete::OnlineStatus::Unknown ||
 	                             oldStatus.status() == Kopete::OnlineStatus::Unknown );
-	if ( contact && Kopete::BehaviorSettings::self() && !inhibitNotification )
+	if ( contact && Kopete::BehaviorSettings::self()->showEvents() && !inhibitNotification )
 	{
 		if ( contact->account() && contact == contact->account()->myself() )
 		{
