@@ -293,6 +293,7 @@ void MainWindow::newConnection(const KUrl &newUrl, bool switchFullscreenWhenConn
 
     int newIndex = m_tabWidget->addTab(scrollArea, KIcon("krdc"), url.prettyUrl(KUrl::RemoveTrailingSlash));
     m_tabWidget->setCurrentIndex(newIndex);
+    tabChanged(newIndex); // force to update m_currentRemoteView (tabChanged is not emitted when start page has been disabled)
 
     view->start();
 }
@@ -642,17 +643,17 @@ void MainWindow::showMenubar()
 
 void MainWindow::closeEvent(QCloseEvent *event)
 {
-    if (KMessageBox::warningYesNoCancel(this,
-                                        i18n("Are you sure you want to close the KDE Remote Desktop Client?"),
-                                        i18n("Confirm Quit"),
-                                        KStandardGuiItem::yes(), KStandardGuiItem::no(), KStandardGuiItem::cancel(),
-                                        "AskBeforeExit") == KMessageBox::Yes) {
+    if (KMessageBox::warningContinueCancel(this,
+                                           i18n("Are you sure you want to close the KDE Remote Desktop Client?"),
+                                           i18n("Confirm Quit"),
+                                           KStandardGuiItem::quit(), KStandardGuiItem::cancel(),
+                                           "DoNotAskBeforeExit") == KMessageBox::Continue) {
 
         if (Settings::rememberSessions()) { // remember open remote views for next startup
             QStringList list;
-            for (int i = (m_showStartPage ? 1 : 0); i < m_tabWidget->count(); i++) {
-                kDebug(5010) << m_remoteViewList.at(i - 1)->url();
-                list.append(m_remoteViewList.at(i - 1)->url().prettyUrl(KUrl::RemoveTrailingSlash));
+            for (int i = 0; i < m_remoteViewList.count(); i++) {
+                kDebug(5010) << m_remoteViewList.at(i)->url();
+                list.append(m_remoteViewList.at(i)->url().prettyUrl(KUrl::RemoveTrailingSlash));
             }
             Settings::setOpenSessions(list);
         }
